function [a,b] = MomentToParamLogisticPDF(mu,sigma,c)
% MomentToParamLogisticPDF: Transforms the mean and the standard deviation to the location
%                           and scale parameters of the logistic distribution.
%
% USAGE:
%
%       [a,b] = MomentToParamLogisticPDF(mu,sigma,c)
%
% REQUIRED INPUT:  mu (vector) with the mean of the logistic distribution.
%
%                  sigma (vector) with the standard deviation of the logistic distribution.
%
%                  c (vector) with shape parameters of the logistic distribution.
%
% REQUIRED OUTPUT: a (vector) with the location parameter of the logistic distribution.
%
%                  b (vector) with the scale parameter of the logistic distribution.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: March 13, 2009.
%                        This version: February 10, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 22-03-2009: Updated the documentation.
%
% * 02-04-2009: Added the input variable c, i.e., the shape parameter of the
%               logistic distribution.
%
% * 03-04-2009: Added the call to DiGamma and TriGamma in case the psi-function is unavailable or
%               not a mex-file.
%
% * 05-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 02-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 27-01-2014: Updated the documentation.
%
% * 13-01-2015: Updated the documentation.
%
% * 20-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

if exist('psi')==3;
   b = sigma./sqrt(((pi^2)/6)+psi(1,c));
   a = mu+((-psi(1)+psi(c)).*b);
else;
   b = sigma./sqrt(((pi^2)/6)+TriGamma(c));
   a = mu+((-DiGamma(1)+DiGamma(c)).*b);
end;

%
% end of MomentToParamLogisticPDF.m
%
