function lnS = logStudentTAltPDF(z,mu,sigma,df)
% logStudentTAltPDF: Computes the height of the log Student-t density.
%
% USAGE:
%
%       lnC = logCauchyPDF(z,mu,sigma)
%
% REQUIRED INPUT:  z (vector) with draws from the Student-t distribution.
%
%                  mu (vector) with location parameters for the Student-t distribution.
%
%                  sigma (vector) with scale parameters for the Student-t distribution.
%
%                  df (integer) with degrees of freedom for the Student-t distribution.
%
% REQUIRED OUTPUT: lnC (vector) with the log height of the Student-t density at z.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: March 12, 2009.
%                        This version: February 10, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 13-03-2009: Updated the documentation.
%
% * 05-01-2010: Updated the documentation.
%
% * 05-01-2011: Updated the documentation.
%
% * 02-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 27-01-2014: Updated the documentation.
%
% * 13-01-2015: Updated the documentation.
%
% * 20-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

lnS = gammaln((df+1)/2)-gammaln(df/2)-((1/2)*log(pi*df))-log(sigma)-(((df+1)/2)*log(1+((1/df)*(((z-mu)./sigma).^2))));

%
% end of logStudentTAltPDF.m
%
