function ModelParameters = UpdateParameters(ModelParameters)
% UpdateParameters: Shows how to define new parameters from previously defined parameters
%
% USAGE:
%
%       ModelParameters = UpdateParameters(ModelParameters)
%
% REQUIRED INPUT:  ModelParameters (structure) with fields corresponding to the parameters
%                                   you need for defining new parameters that should be
%                                   added to the structure.
%
% REQUIRED OUTPUT: ModelParameters (structure) with additions to the input structure.
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: June 25, 2015.
%                        This version: February 10, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 02-07-2015: Updated the documentation.
%
% * 21-01-2016: Updated the documentation.
%
% * 10-02-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

ModelParameters.gamma = (ModelParameters.gammabar/100)+1;
ModelParameters.pistar = (ModelParameters.pibar/100)+1;
ModelParameters.beta = 1/((ModelParameters.betainv/100)+1);
ModelParameters.betabar = ModelParameters.beta*(ModelParameters.gamma^(-ModelParameters.sigmac));
ModelParameters.rbar = 100*((ModelParameters.pistar/ModelParameters.betabar)-1);

%
% end of UpdateParameters.m
%
