function SplitPosMatrix = SplitNaNVector(A)
% SplitNaNVector: Splits the input vector A where there are NaN's and provided split indices.
%
% USAGE:
%
%       SplitPosMatrix = SplitNaNVector(A)
%
% REQUIRED INPUT:  A (vector) of dimension n with some NaNs.
%
% REQUIRED OUTPUT: SplitPosMatrix (matrix) of dimension kx2 where each row holds positions
%                                 in the A matrix where the values are not NaN. The number
%                                 of columns is each to the number of subvectors inside A
%                                 with noninterupted non NaN values, where the first columns
%                                 gives the first position and the second the last position
%                                 of this subvector in A.
%
% EXAMPLE:
%
%         A = [-1 0 NaN (2:8) NaN (10:11) NaN NaN (14:20) NaN (22:26)];
%
% yields
%
%       SplitPosMatrix = [1 2;4 10;12 13;16 22;24 28];
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/MPR
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: March 17, 2011.
%                        This version: March 21, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 18-03-2011: Updated the documentation.
%
% * 04-01-2012: Updated the documentation.
%
% * 03-01-2013: Updated the documentation.
%
% * 28-01-2014: Updated the documentation.
%
% * 14-01-2015: Updated the documentation.
%
% * 27-01-2016: Remember Shoah.
%
% * 21-03-2017: Updated the documentation.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                 

SplitPosMatrix = [];
A = A(:);
n = length(A);
pos = isnan(A).*(1:n)';
pos = pos(pos>0);
m = length(pos);
if m==n;
   return;
elseif m==0;
   SplitPosMatrix = [1 n];
   return;
end;
for j=1:m;
   if j>1;
      if j<m;
         if pos(j)+1<pos(j+1);
            SplitPosMatrix = [SplitPosMatrix;pos(j)+1 pos(j+1)-1];
         end;
      else;
         if pos(j)<n;
            SplitPosMatrix = [SplitPosMatrix;pos(j)+1 n];
         end;
      end;
   else;
      if pos(j)>1;
         SplitPosMatrix = [1 pos(j)-1];
      end;
      if (m>1)&(pos(1)+1<pos(2));
         SplitPosMatrix = [SplitPosMatrix;pos(1)+1 pos(2)-1];
      elseif (m==1)&pos(1)<n;
         SplitPosMatrix = [SplitPosMatrix;pos(1)+1 n];
      end;
   end;
end;

%
% end of SplitNaNVector.m
%
